| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Llama.Internal.Foreign.Split
Documentation
Arguments
| :: CString | |
| -> CSize | |
| -> CString | |
| -> CInt | |
| -> CInt | |
| -> IO CInt | Returns length of written string or required buffer size |
LLAMA_API int llama_split_path(char * split_path, size_t maxlen, const char * path_prefix, int split_no, int split_count);
Arguments
| :: CString | |
| -> CSize | |
| -> CString | |
| -> CInt | |
| -> CInt | |
| -> IO CInt | Returns length of written string or required buffer size |
LLAMA_API int llama_split_prefix(char * split_prefix, size_t maxlen, const char * split_path, int split_no, int split_count);
c_llama_print_system_info Source #
LLAMA_API const char * llama_print_system_info(void);